==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/nl-NL/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Een gebruiker heeft een artikel geaccepteerd',
    'acceptance_asset_declined' => 'Een gebruiker heeft een artikel geweigerd',
    'a_user_canceled' => 'Een gebruiker heeft een verzoek om een item op de website geannuleerd',
    'a_user_requested' => 'Een gebruiker heeft een item op de website aangevraagd',
    'accessory_name' => 'Accessoire Naam:',
    'additional_notes' => 'Aanvullende Notities:',
    'admin_has_created' => 'Een beheerder heeft een account voor u aangemaakt op de :web website.',
    'asset' => 'Asset:',
    'asset_name' => 'Asset naam:',
    'asset_requested' => 'Asset aangevraagd',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Toegewezen aan',
    'best_regards' => 'Met vriendelijke groeten,',
    'canceled' => 'Geannuleerd:',
    'checkin_date' => 'Datum ingecheckt:',
    'checkout_date' => 'Datum uitgecheckt:',
    'click_to_confirm' => 'Klik op de volgende link om uw :web account te bevestigen:',
    'click_on_the_link_accessory' => 'Klik op de link onderaan om te bevestigen dat u de accessoire hebt ontvangen.',
    'click_on_the_link_asset' => 'Klik op de link onderaan om te bevestigen dat u het asset hebt ontvangen.',
    'Confirm_Asset_Checkin' => 'Asset check in bevestiging',
    'Confirm_Accessory_Checkin' => 'Accessoire check in bevestiging',
    'Confirm_accessory_delivery' => 'Accessoire uitlevering bevestiging',
    'Confirm_license_delivery' => 'Bevestiging licentie uitlevering',
    'Confirm_asset_delivery' => 'Bevestiging asset uitlevering',
    'Confirm_consumable_delivery' => 'Bevestiging uitlevering verbruiksartikel',
    'current_QTY' => 'Huidige hoeveelheid',
    'Days' => 'Dagen',
    'days' => 'Dagen',
    'expecting_checkin_date' => 'Verwachte incheck datum:',
    'expires' => 'Verloopt',
    'Expiring_Assets_Report' => 'Rapport van verlopen activa',
    'Expiring_Licenses_Report' => 'Rapportage verlopende licenties.',
    'hello' => 'Hallo',
    'hi' => 'Hoi',
    'i_have_read' => 'Ik heb de gebruiksvoorwaarden gelezen en geaccepteerd en heb dit item ontvangen.',
    'item' => 'Item:',
    'Item_Request_Canceled' => 'Item aanvraag geannuleerd',
    'Item_Requested' => 'Item aangevraagd',
    'link_to_update_password' => 'Klik op de volgende link om je :web wachtwoord te vernieuwen:',
    'login_first_admin' => 'Meld u aan op uw nieuwe Snipe-IT installatie met onderstaande inloggegevens:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Lage inventarisrapport',
    'inventory_report' => 'Inventarisrapport',
    'min_QTY' => 'Minimale hoeveelheid',
    'name' => 'Naam',
    'new_item_checked' => 'Een nieuw item is onder uw naam uitgecheckt, details staan hieronder.',
    'password' => 'Wachtwoord:',
    'password_reset' => 'Wachtwoord opnieuw instellen',

    'read_the_terms' => 'Lees alstublieft de onderstaande gebruiksovereenkomst.',
    'read_the_terms_and_click' => 'Gelieve de onderstaande gebruiksvoorwaarden te lezen, en klik op de link onderaan om te bevestigen dat je
                         hebt gelezen en akkoord gaat met de gebruiksvoorwaarden en hebben het asset ontvangen.',
    'requested' => 'Aangevraagd:',
    'reset_link' => 'Je Wachtwoord Herstel Link',
    'reset_password' => 'Klik hier om uw wachtwoord opnieuw in te stellen:',
    'serial' => 'Serienummer',
    'supplier' => 'Leverancier',
    'tag' => 'Tag',
    'test_email' => 'Test e-mail van Snipe-IT',
    'test_mail_text' => 'Dit is een test van het Asset Management Systeem. Als je dit hebt ontvangen, werkt de mail :)',
    'the_following_item' => 'Het volgende item is ingecheckt: ',
    'low_inventory_alert' => 'Er is :count item dat onder de minimumvoorraad ligt of binnenkort laag zal zijn.|Er zijn :count items die onder de minimumvoorraad zijn of binnenkort laag zullen zijn.',
    'assets_warrantee_alert' => 'Er is :count asset met een garantie die afloopt in de volgende :threshold dagen.|Er zijn :count assets met garanties die vervallen in de volgende :threshold dagen.',
    'license_expiring_alert' => 'Er is :count licentie die afloopt in de volgende :threshold dagen.|Er zijn :count licenties die vervallen in de volgende :threshold dagen.',
    'to_reset' => 'Vul dit formulier in om je :web wachtwoord te resetten:',
    'type' => 'Type',
    'upcoming-audits' => 'Er is :count asset die binnen :threshold dagen gecontroleerd moet worden.|Er zijn :count assets die binnen :threshold dagen gecontroleerd moeten worden.',
    'user' => 'Gebruiker',
    'username' => 'Gebruikersnaam',
    'welcome' => 'Welkom :name',
    'welcome_to' => 'Welkom bij :web!',
    'your_credentials' => 'Je Snipe-IT inloggegevens',
    'Accessory_Checkin_Notification' => 'Accessoire ingecheckt',
    'Asset_Checkin_Notification' => 'Asset ingecheckt',
    'Asset_Checkout_Notification' => 'Asset uitgecheckt',
    'License_Checkin_Notification' => 'Licentie ingecheckt',
    'Expected_Checkin_Report' => 'Verwachte asset check in rapport',
    'Expected_Checkin_Notification' => 'Herinnering: :name check in deadline nadert',
    'Expected_Checkin_Date' => 'Een asset uitgecheckt aan jou moet worden ingecheckt op :date',
    'your_assets' => 'Bekijk je activa',
    'rights_reserved' => 'Alle rechten voorbehouden.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/nl-NL/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessoire ingecheckt',
    'Accessory_Checkout_Notification' => 'Accessoire uitgecheckt',
    'Asset_Checkin_Notification' => 'Asset ingecheckt',
    'Asset_Checkout_Notification' => 'Asset uitgecheckt',
    'Confirm_Accessory_Checkin' => 'Accessoire check in bevestiging',
    'Confirm_Asset_Checkin' => 'Asset check in bevestiging',
    'Confirm_accessory_delivery' => 'Accessoire uitlevering bevestiging',
    'Confirm_asset_delivery' => 'Bevestiging asset uitlevering',
    'Confirm_consumable_delivery' => 'Bevestiging uitlevering verbruiksartikel',
    'Confirm_license_delivery' => 'Bevestiging licentie uitlevering',
    'Consumable_checkout_notification' => 'Verbruiksartikel uitgecheckt',
    'Days' => 'Dagen',
    'Expected_Checkin_Date' => 'Een asset uitgecheckt aan jou moet worden ingecheckt op :date',
    'Expected_Checkin_Notification' => 'Herinnering: :name check in deadline nadert',
    'Expected_Checkin_Report' => 'Verwachte asset check in rapport',
    'Expiring_Assets_Report' => 'Rapport van verlopen activa',
    'Expiring_Licenses_Report' => 'Rapportage verlopende licenties.',
    'Item_Request_Canceled' => 'Item aanvraag geannuleerd',
    'Item_Requested' => 'Item aangevraagd',
    'License_Checkin_Notification' => 'Licentie ingecheckt',
    'License_Checkout_Notification' => 'Licentie gecontroleerd',
    'Low_Inventory_Report' => 'Lage inventarisrapport',
    'a_user_canceled' => 'Een gebruiker heeft een verzoek om een item op de website geannuleerd',
    'a_user_requested' => 'Een gebruiker heeft een item op de website aangevraagd',
    'acceptance_asset_accepted' => 'Een gebruiker heeft een artikel geaccepteerd',
    'acceptance_asset_declined' => 'Een gebruiker heeft een artikel geweigerd',
    'accessory_name' => 'Accessoire Naam:',
    'additional_notes' => 'Aanvullende Notities:',
    'admin_has_created' => 'Een beheerder heeft een account voor u aangemaakt op de :web website.',
    'asset' => 'Asset:',
    'asset_name' => 'Asset naam:',
    'asset_requested' => 'Asset aangevraagd',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'Er is :count asset met een garantie die afloopt in de volgende :threshold dagen.|Er zijn :count assets met garanties die vervallen in de volgende :threshold dagen.',
    'assigned_to' => 'Toegewezen aan',
    'best_regards' => 'Met vriendelijke groeten,',
    'canceled' => 'Geannuleerd:',
    'checkin_date' => 'Datum ingecheckt:',
    'checkout_date' => 'Datum uitgecheckt:',
    'checkedout_from' => 'Uitgecheckt van',
    'checkedin_from'  => 'Ingecheckt op',
    'checked_into' => 'Ingecheckt bij',
    'click_on_the_link_accessory' => 'Klik op de link onderaan om te bevestigen dat u de accessoire hebt ontvangen.',
    'click_on_the_link_asset' => 'Klik op de link onderaan om te bevestigen dat u het asset hebt ontvangen.',
    'click_to_confirm' => 'Klik op de volgende link om uw :web account te bevestigen:',
    'current_QTY' => 'Huidige hoeveelheid',
    'days' => 'Dagen',
    'expecting_checkin_date' => 'Verwachte incheck datum:',
    'expires' => 'Verloopt',
    'hello' => 'Hallo',
    'hi' => 'Hoi',
    'i_have_read' => 'Ik heb de gebruiksvoorwaarden gelezen en geaccepteerd en heb dit item ontvangen.',
    'inventory_report' => 'Inventarisrapport',
    'item' => 'Item:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Er is :count licentie die afloopt in de volgende :threshold dagen.|Er zijn :count licenties die vervallen in de volgende :threshold dagen.',
    'link_to_update_password' => 'Klik op de volgende link om je :web wachtwoord te vernieuwen:',
    'login' => 'Login:',
    'login_first_admin' => 'Meld u aan op uw nieuwe Snipe-IT installatie met onderstaande inloggegevens:',
    'low_inventory_alert' => 'Er is :count item dat onder de minimumvoorraad ligt of binnenkort laag zal zijn.|Er zijn :count items die onder de minimumvoorraad zijn of binnenkort laag zullen zijn.',
    'min_QTY' => 'Minimale hoeveelheid',
    'name' => 'Naam',
    'new_item_checked' => 'Een nieuw item is onder uw naam uitgecheckt, details staan hieronder.',
    'notes' => 'Opmerkingen',
    'password' => 'Wachtwoord:',
    'password_reset' => 'Wachtwoord opnieuw instellen',
    'read_the_terms' => 'Lees alstublieft de onderstaande gebruiksovereenkomst.',
    'read_the_terms_and_click' => 'Gelieve de onderstaande gebruiksvoorwaarden te lezen, en klik op de link onderaan om te bevestigen dat je de gebruiksvoorwaarden leest en accepteert en het bestand hebt ontvangen.',
    'requested' => 'Aangevraagd:',
    'reset_link' => 'Je Wachtwoord Herstel Link',
    'reset_password' => 'Klik hier om uw wachtwoord opnieuw in te stellen:',
    'rights_reserved' => 'Alle rechten voorbehouden.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT integratietest',
    'snipe_webhook_summary' => 'Samenvatting Snipe-IT-integratie Test',
    'supplier' => 'Leverancier',
    'tag' => 'Tag',
    'test_email' => 'Test e-mail van Snipe-IT',
    'test_mail_text' => 'Dit is een test van het Asset Management Systeem. Als je dit hebt ontvangen, werkt de mail :)',
    'the_following_item' => 'Het volgende item is ingecheckt: ',
    'to_reset' => 'Vul dit formulier in om je :web wachtwoord te resetten:',
    'type' => 'Type',
    'upcoming-audits' => 'Er is :count asset die binnen :threshold dagen gecontroleerd moet worden.|Er zijn :count assets die binnen :threshold dagen gecontroleerd moeten worden.',
    'user' => 'Gebruiker',
    'username' => 'Gebruikersnaam',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Welkom :name',
    'welcome_to' => 'Welkom bij :web!',
    'your_assets' => 'Bekijk je activa',
    'your_credentials' => 'Je Snipe-IT inloggegevens',
    'mail_sent' => 'Mail sent successfully!',
];
